@@ -12,7 +12,6 @@
 #include <QApplication>
 #include <QLayout>
 
-
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDBusInterface>
@@ -24,11 +23,12 @@
 #include <KLocalizedString>
 
 #include <kcmoduleloader.h>
+#include <kcmoduleqml_p.h>
 
 #include <KColorScheme>
 
-#include <kcmutils_debug.h>
 #include "ksettingswidgetadaptor.h"
+#include <kcmutils_debug.h>
 
 /*
  TODO:
@@ -61,7 +61,6 @@ void KCModuleProxyPrivate::loadModule()
 {
     if (!topLayout) {
         topLayout = new QVBoxLayout(parent);
-        topLayout->setContentsMargins(0, 0, 0, 0);
 
         QString name = modInfo.handle();
         name.replace(QLatin1Char('-'), QLatin1Char('_')); // hyphen is not allowed in dbus, only [A-Z][a-z][0-9]_
@@ -76,7 +75,8 @@ void KCModuleProxyPrivate::loadModule()
     if (QDBusConnection::sessionBus().registerService(dbusService) || bogusOccupier) {
         /* We got the name we requested, because no one was before us,
          * or, it was an random application which had picked that name */
-        // qDebug() << "Module not already loaded, loading module " << modInfo.moduleName() << " from library " << modInfo.library() << " using symbol " << modInfo.handle();
+        // qDebug() << "Module not already loaded, loading module " << modInfo.moduleName() << " from library " << modInfo.library() << " using symbol " <<
+        // modInfo.handle();
 
         kcm = KCModuleLoader::loadModule(modInfo, KCModuleLoader::Inline, parent, args);
 
@@ -89,6 +89,10 @@ void KCModuleProxyPrivate::loadModule()
         if (kcm->layout()) {
             kcm->layout()->setContentsMargins(0, 0, 0, 0);
         }
+        if (qobject_cast<KCModuleQml *>(kcm)) {
+            topLayout->setContentsMargins(0, 0, 0, 0);
+        }
+
         topLayout->addWidget(kcm);
         if (!modInfo.handle().isEmpty()) {
             QDBusConnection::sessionBus().registerObject(dbusPath, new KSettingsWidgetAdaptor(parent), QDBusConnection::ExportAllSlots);
@@ -101,11 +105,17 @@ void KCModuleProxyPrivate::loadModule()
         QDBusReply<QString> reply = proxy.call(QStringLiteral("applicationName"));
 
         if (reply.isValid()) {
-            QObject::connect(QDBusConnection::sessionBus().interface(), SIGNAL(serviceOwnerChanged(QString,QString,QString)),
-                             parent, SLOT(_k_ownerChanged(QString,QString,QString)));
+            QObject::connect(QDBusConnection::sessionBus().interface(),
+                             SIGNAL(serviceOwnerChanged(QString, QString, QString)),
+                             parent,
+                             SLOT(_k_ownerChanged(QString, QString, QString)));
             kcm = KCModuleLoader::reportError(KCModuleLoader::Inline,
-                                              i18nc("Argument is application name", "This configuration section is "
-                                                    "already opened in %1",  reply.value()), QStringLiteral(" "), parent);
+                                              i18nc("Argument is application name",
+                                                    "This configuration section is "
+                                                    "already opened in %1",
+                                                    reply.value()),
+                                              QStringLiteral(" "),
+                                              parent);
             topLayout->addWidget(kcm);
         } else {
             // qDebug() << "Calling KCModuleProxy's DBus interface for fetching the name failed.";
@@ -142,7 +152,6 @@ void KCModuleProxy::showEvent(QShowEvent *ev)
     }
 
     QWidget::showEvent(ev);
-
 }
 
 KCModuleProxy::~KCModuleProxy()
@@ -168,8 +177,8 @@ void KCModuleProxyPrivate::_k_moduleChanged(bool c)
 
     Q_Q(KCModuleProxy);
     changed = c;
-    emit q->changed(c);
-    emit q->changed(q);
+    Q_EMIT q->changed(c);
+    Q_EMIT q->changed(q);
 }
 
 void KCModuleProxyPrivate::_k_moduleDefaulted(bool d)
@@ -180,8 +189,8 @@ void KCModuleProxyPrivate::_k_moduleDefaulted(bool d)
 
     Q_Q(KCModuleProxy);
     defaulted = d;
-    emit q->changed(changed);
-    emit q->changed(q);
+    Q_EMIT q->changed(changed);
+    Q_EMIT q->changed(q);
 }
 
 void KCModuleProxyPrivate::_k_moduleDestroyed()
@@ -189,23 +198,23 @@ void KCModuleProxyPrivate::_k_moduleDestroyed()
     kcm = nullptr;
 }
 
-KCModuleProxy::KCModuleProxy(const KService::Ptr &service, QWidget *parent,
-                             const QStringList &args)
-    : QWidget(parent), d_ptr(new KCModuleProxyPrivate(this, KCModuleInfo(service), args))
+KCModuleProxy::KCModuleProxy(const KService::Ptr &service, QWidget *parent, const QStringList &args)
+    : QWidget(parent)
+    , d_ptr(new KCModuleProxyPrivate(this, KCModuleInfo(service), args))
 {
     d_ptr->q_ptr = this;
 }
 
-KCModuleProxy::KCModuleProxy(const KCModuleInfo &info, QWidget *parent,
-                             const QStringList &args)
-    : QWidget(parent), d_ptr(new KCModuleProxyPrivate(this, info, args))
+KCModuleProxy::KCModuleProxy(const KCModuleInfo &info, QWidget *parent, const QStringList &args)
+    : QWidget(parent)
+    , d_ptr(new KCModuleProxyPrivate(this, info, args))
 {
     d_ptr->q_ptr = this;
 }
 
-KCModuleProxy::KCModuleProxy(const QString &serviceName, QWidget *parent,
-                             const QStringList &args)
-    : QWidget(parent), d_ptr(new KCModuleProxyPrivate(this, KCModuleInfo(serviceName), args))
+KCModuleProxy::KCModuleProxy(const QString &serviceName, QWidget *parent, const QStringList &args)
+    : QWidget(parent)
+    , d_ptr(new KCModuleProxyPrivate(this, KCModuleInfo(serviceName), args))
 {
     d_ptr->q_ptr = this;
 }
@@ -297,11 +306,10 @@ void KCModuleProxy::setDefaultsIndicatorsVisible(bool show)
     }
 }
 
-//X void KCModuleProxy::emitQuickHelpChanged()
-//X {
-//X     emit quickHelpChanged();
-//X }
+// X void KCModuleProxy::emitQuickHelpChanged()
+// X {
+// X     emit quickHelpChanged();
+// X }
 
 /***************************************************************/
 #include "moc_kcmoduleproxy.cpp"
-
